==> kde4libs_3.80.1.orig.tar.gz: kde4libs-3.80.1/sonnet/spelling/loader.h <==
// -*- Mode: C++; c-basic-offset: 4; indent-tabs-mode: nil; -*-
/**
 * loader.h
 *
 * Copyright (C)  2003  Zack Rusin <zack@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_BROKER_H
#define KSPELL_BROKER_H

#include <kdelibs_export.h>
#include <ksharedptr.h>

#include <qobject.h>
#include <qstringlist.h>
#include <qstring.h>
#include <kconfig.h>

class KService;
namespace KSpell2
{
    class Settings;
    class Speller;
    class DefaultDictionary;

    /**
     * @short Class used to deal with dictionaries
     *
     * This class manages all dictionaries. It's the top level
     * KSpell2 class, you can think of it as the kernel or manager
     * of the KSpell2 architecture.
     */
    class KSPELL2_EXPORT Loader : public QObject,
                                  public KShared
    {
        Q_OBJECT
    public:
        typedef KSharedPtr<Loader> Ptr;
        /**
         * Constructs the loader.
         *
         * It's very important that you leave the return value in a Loader::Ptr.
         * Loader is reference counted so if you don't want to have it deleted
         * under you simply have to hold it in a Loader::Ptr for as long as
         * you're using it.
         *
         * @param config is the name of config file which
         *        loader should use to read default language
         *        and default client values. If no value will
         *        be passed Loader will use global kspellrc file.
         */
        static Loader::Ptr openLoader(
            KSharedConfig::Ptr config = KSharedConfig::Ptr());

    public:
        ~Loader();

        /**
         * Function returns the so-called DefaultDictionary. It's a
         * special form a dictionary which automatically mutates
         * according to changes tot the KSpell2::Settings object.
         * You also can't delete it like other dictionaries since
         * it's owned by the Loader and it will take care of it.
         */
        DefaultDictionary *defaultDictionary() const;

        /**
         * Returns dictionary for the given language and preferred client.
         *
         * @param language specifies the language of the dictionary. If an
         *        empty string will be passed the default language will
         *        be used. Has to be one of the values returned by
         *        \ref languages()
         * @param client specifies the preferred client. If no client is
         *               specified a client which supports the given
         *               language is picked. If a few clients supports
         *               the same language the one with the biggest
         *               reliability value is returned.
         *
         */
        Speller *createSpeller(
            const QString& language = QString(),
            const QString& client = QString()) const;

        /**
         * Returns names of all supported clients (e.g. ISpell, ASpell)
         */
        QStringList clients() const;

        /**
         * Returns a list of supported languages.
         */
        QStringList languages() const;

        /**
         * Returns a localized list of names of supported languages.
         */
        QStringList languagesName() const;

        /**
         * Returns the Settings object used by the loader.
         */
        Settings *settings() const;
    Q_SIGNALS:
        /**
         * Signal is emitted whenever the Settings object
         * associated with this Loader changes.
         */
        void configurationChanged();

    protected:
        friend class Settings;
        void changed();
    private:
        Loader(KSharedConfig::Ptr config);
        void loadPlugins();
        void loadPlugin(const KSharedPtr<KService>&);
        mutable QStringList languagesNameCache;
    private:
        class Private;
        Private* const d;
    };
}

#endif

==> kde4libs_3.80.3.orig.tar.gz: kde4libs-3.80.3/sonnet/spelling/loader.h <==
// -*- Mode: C++; c-basic-offset: 4; indent-tabs-mode: nil; -*-
/**
 * loader.h
 *
 * Copyright (C)  2003  Zack Rusin <zack@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA
 */
#ifndef KSPELL_BROKER_H
#define KSPELL_BROKER_H

#include <kdelibs_export.h>
#include <ksharedptr.h>

#include <qobject.h>
#include <qstringlist.h>
#include <qstring.h>
#include <kconfig.h>

class KService;
namespace KSpell2
{
    class Settings;
    class Speller;
    class DefaultDictionary;

    /**
     * @short Class used to deal with dictionaries
     *
     * This class manages all dictionaries. It's the top level
     * KSpell2 class, you can think of it as the kernel or manager
     * of the KSpell2 architecture.
     */
    class SONNETCORE_EXPORT Loader : public QObject,
                                     public KShared
    {
        Q_OBJECT
    public:
        typedef KSharedPtr<Loader> Ptr;
        /**
         * Constructs the loader.
         *
         * It's very important that you leave the return value in a Loader::Ptr.
         * Loader is reference counted so if you don't want to have it deleted
         * under you simply have to hold it in a Loader::Ptr for as long as
         * you're using it.
         *
         * @param config is the name of config file which
         *        loader should use to read default language
         *        and default client values. If no value will
         *        be passed Loader will use global kspellrc file.
         */
        static Loader::Ptr openLoader(
            KSharedConfig::Ptr config = KSharedConfig::Ptr());

    public:
        ~Loader();

        /**
         * Function returns the so-called DefaultDictionary. It's a
         * special form a dictionary which automatically mutates
         * according to changes tot the KSpell2::Settings object.
         * You also can't delete it like other dictionaries since
         * it's owned by the Loader and it will take care of it.
         */
        DefaultDictionary *defaultDictionary() const;

        /**
         * Returns dictionary for the given language and preferred client.
         *
         * @param language specifies the language of the dictionary. If an
         *        empty string will be passed the default language will
         *        be used. Has to be one of the values returned by
         *        \ref languages()
         * @param client specifies the preferred client. If no client is
         *               specified a client which supports the given
         *               language is picked. If a few clients supports
         *               the same language the one with the biggest
         *               reliability value is returned.
         *
         */
        Speller *createSpeller(
            const QString& language = QString(),
            const QString& client = QString()) const;

        /**
         * Returns names of all supported clients (e.g. ISpell, ASpell)
         */
        QStringList clients() const;

        /**
         * Returns a list of supported languages.
         */
        QStringList languages() const;

        /**
         * Returns a localized list of names of supported languages.
         */
        QStringList languagesName() const;

        /**
         * Returns the Settings object used by the loader.
         */
        Settings *settings() const;
    Q_SIGNALS:
        /**
         * Signal is emitted whenever the Settings object
         * associated with this Loader changes.
         */
        void configurationChanged();

    protected:
        friend class Settings;
        void changed();
    private:
        Loader(KSharedConfig::Ptr config);
        void loadPlugins();
        void loadPlugin(const KSharedPtr<KService>&);
        mutable QStringList languagesNameCache;
    private:
        class Private;
        Private* const d;
    };
}

#endif
